@@ -6,24 +6,49 @@ import openai
 import pyperclip
 import os
 from urllib.parse import quote
-from simple_term_menu import TerminalMenu
 import platform
 
-import copilot.history as history
+if platform.system().lower().startswith("lin") or platform.system().lower().startswith(
+    "dar"
+):
+    from simple_term_menu import TerminalMenu
+elif platform.system().lower().startswith("win"):
+    import inquirer
+
+from copilot import history
+
+
+if platform.system().lower().startswith("lin") or platform.system().lower().startswith(
+    "dar"
+):
+    from simple_term_menu import TerminalMenu
+elif platform.system().lower().startswith("win"):
+    import inquirer
 
 
 def main():
-    parser = argparse.ArgumentParser(prog='copilot', description='Terminal Copilot')
-    parser.add_argument('command', type=str, nargs='+',
-                        help='Describe the command you are looking for.')
-    parser.add_argument('-a', '--alias', action='store_true',
-                        help='Include aliases in the prompt. Note: This feature may potentially send sensitive information to OpenAI.')
-    parser.add_argument('-v', '--verbose', action='store_true',
-                        help='increase output verbosity')
-    parser.add_argument('-g', '--git', action='store_true',
-                        help='Include git info if available')
-    parser.add_argument('-hist', '--history', action='store_true',
-                        help='Include terminal history in the prompt. Note: This feature may potentially send sensitive information to OpenAI and increase the number of tokens used.')
+    parser = argparse.ArgumentParser(prog="copilot", description="Terminal Copilot")
+    parser.add_argument(
+        "command", type=str, nargs="+", help="Describe the command you are looking for."
+    )
+    parser.add_argument(
+        "-a",
+        "--alias",
+        action="store_true",
+        help="Include aliases in the prompt. Note: This feature may potentially send sensitive information to OpenAI.",
+    )
+    parser.add_argument(
+        "-v", "--verbose", action="store_true", help="increase output verbosity"
+    )
+    parser.add_argument(
+        "-g", "--git", action="store_true", help="Include git info if available"
+    )
+    parser.add_argument(
+        "-hist",
+        "--history",
+        action="store_true",
+        help="Include terminal history in the prompt. Note: This feature may potentially send sensitive information to OpenAI and increase the number of tokens used.",
+    )
 
     args = parser.parse_args()
 
@@ -39,8 +64,19 @@ def main():
         if key in os.environ:
             environs += f"{key}={os.environ[key]}\n"
 
-    shell = os.environ["SHELL"]
     operating_system = platform.system()
+    if operating_system.lower().startswith(
+        "lin"
+    ) or operating_system.lower().startswith("dar"):
+        shell = os.environ.get("SHELL")
+    elif operating_system.lower().startswith("win"):
+        shell = "cmd"
+
+    # get the current directory
+    current_dir = os.getcwd()
+
+    # list the files in the current directory
+    directory_list = os.listdir()
 
     prompt = f"""
 You are an AI Terminal Copilot. Your job is to help users find the right terminal command in a {shell} on {operating_system}.
@@ -49,15 +85,19 @@ The user is asking for the following command:
 '{" ".join(args.command)}'
 
 The user is currently in the following directory:
-{subprocess.run(["pwd"], capture_output=True).stdout.decode("utf-8")}
+{current_dir}
 That directory contains the following files:
-{subprocess.run(["ls"], capture_output=True).stdout.decode("utf-8")}
-{history.get_history() if args.history else ""}
+{directory_list}
+{history.get_history() if args.history and operating_system.lower().startswith("lin") or operating_system.lower().startswith("dar") else ""}
 The user has several environment variables set, some of which are:
 {environs}
 {git_info() if args.git else ""}
 """
-    if args.alias:
+    if (
+        args.alias
+        and operating_system.lower().startswith("lin")
+        or operating_system.lower().startswith("dar")
+    ):
         prompt += f"""
 The user has the following aliases set:
 {subprocess.run(["history"], capture_output=True, shell=True).stdout.decode("utf-8")}
@@ -85,10 +125,27 @@ The command the user is looking for is:
 
 
 def show_command_options(prompt, cmd):
+    operating_system = platform.system()
+
     print(f"\033[94m> {cmd}\033[0m")
     options = ["execute", "copy", "explainshell", "show more options"]
-    terminal_menu = TerminalMenu(options)
-    menu_entry_index = terminal_menu.show()
+
+    if operating_system.lower().startswith(
+        "lin"
+    ) or operating_system.lower().startswith("dar"):
+        terminal_menu = TerminalMenu(options)
+        menu_entry_index = terminal_menu.show()
+    elif operating_system.lower().startswith("win"):
+        questions = [
+            inquirer.List(
+                "menu_entry_index",
+                message="What do you want to do?",
+                choices=options,
+            ),
+        ]
+        answers = inquirer.prompt(questions)
+        menu_entry_index = options.index(answers["menu_entry_index"])
+
     if menu_entry_index == 0:
         execute(cmd)
     elif menu_entry_index == 1:
@@ -108,11 +165,28 @@ def execute(cmd):
 
 
 def show_more_cmd_options(prompt):
+    operating_system = platform.system()
+
     cmds = request_cmds(prompt, n=5)
     print("Here are more options:")
     options = [repr(cmd) for cmd in cmds]
-    cmd_terminal_menu = TerminalMenu(options)
-    cmd_menu_entry_index = cmd_terminal_menu.show()
+
+    if operating_system.lower().startswith(
+        "lin"
+    ) or operating_system.lower().startswith("dar"):
+        cmd_terminal_menu = TerminalMenu(options)
+        cmd_menu_entry_index = cmd_terminal_menu.show()
+    elif operating_system.lower().startswith("win"):
+        questions = [
+            inquirer.List(
+                "cmd_menu_entry_index",
+                message="Which command do you want to execute?",
+                choices=options,
+            ),
+        ]
+        answers = inquirer.prompt(questions)
+        cmd_menu_entry_index = options.index(answers["cmd_menu_entry_index"])
+
     if cmd_menu_entry_index is not None:
         show_command_options(prompt, cmds[cmd_menu_entry_index])
 
@@ -141,7 +215,9 @@ def strip_all_whitespaces_from(choices):
 
 
 def git_info():
-    git_installed = subprocess.run(["which", "git"], capture_output=True).returncode == 0
+    git_installed = (
+        subprocess.run(["which", "git"], capture_output=True).returncode == 0
+    )
     if os.path.exists(".git") and git_installed:
         return f"""
 User is in a git repo.
